#!/usr/bin/env python3

import json
import sys
import os
import _jsonnet
import requests

# Rack awareness logic
node_labels = []
rack_labels = []
env_var = 'RACK_NODE_LABELS'
token_path = '/var/run/secrets/kubernetes.io/serviceaccount/token'
if env_var in os.environ:
    rack_labels = json.loads(os.environ[env_var])
    service_host = os.environ['KUBERNETES_SERVICE_HOST']
    tcp_port = os.environ['KUBERNETES_SERVICE_PORT_HTTPS']
    hostname = os.environ['HOSTNAME']
    namespace = os.environ['POD_NAMESPACE']

    with open(token_path) as f:
        kube_token = f.read()
    headers = {'Authorization': 'Bearer %s' % kube_token}

    # get label value for rack awareness node label
    api_url = 'https://%s:%s/api/v1/' % (service_host, tcp_port)

    r = requests.get(api_url + 'namespaces/%s/pods/%s' % (namespace, hostname), headers=headers, verify=False)
    if r.status_code != 200:
        sys.exit(r.json())
    node_name = r.json()['spec']['nodeName']

    r = requests.get(api_url + 'nodes/%s' % node_name, headers=headers, verify=False)
    if r.status_code != 200:
        sys.exit(r.json())

    node_labels = r.json()['metadata']['labels']
    for label in rack_labels:
        if label not in node_labels:
            sys.exit('node label: %s not found in pod node metadata' % label)

pod_name = sys.argv[1]
data_file = sys.argv[2]
jsonnet_file = sys.argv[3]
output_file = sys.argv[4]

with open(data_file) as df:
    data = json.load(df)

with open(jsonnet_file, "r") as jf:
    jsonnet_str = jf.read()

json_str = _jsonnet.evaluate_snippet(
    "snippet",
    jsonnet_str,
    ext_vars={
        'podName': pod_name,
        'data': json.dumps(data),
        'nodeLabels': json.dumps(node_labels),
        'rackLabels': json.dumps(rack_labels)
    },
)

json_obj = json.loads(json_str)
with open(output_file, 'w') as of:
    json.dump(json_obj, of)



#!/usr/bin/env python3

import sys
import json
import os

ZIP_EXTENSION = ".zip"

plugins_json_file = sys.argv[1]
output_file = sys.argv[2]

def get_file_name(path, name, type):
    return path + '/' + name + type

with open(plugins_json_file) as pf:
    plugins_object = json.load(pf)

with open(output_file, 'w+') as of:
    of.write('#!/usr/bin/env sh \n')

    confluentHubPlugins = plugins_object['ConfluentHubPlugins']
    if confluentHubPlugins is not None:
        for plugin in confluentHubPlugins:
            of.write(f"confluent connect plugin install {plugin['Name']} --force --worker-configurations /dev/null --plugin-directory /mnt/plugins {plugin['ExtraArgs']} \n")

    urlPlugins = plugins_object['RemoteURLPlugins']
    if urlPlugins is not None:
        for plugin in urlPlugins:
            filename = get_file_name("/mnt/plugins", plugin['Name'], ZIP_EXTENSION)
            # download file. set ""--max-redirect 0" for CVE-2021-31879
            of.write(f"wget --max-redirect 0 \"{plugin['ArchivePath']}\" -O {filename} -P /mnt/plugins {plugin['WgetExtraArgs']} \n")

            # verify checksum
            sha512filename = get_file_name("/mnt/plugins", plugin['Name'], '.sha512')
            of.write(f"echo {plugin['Checksum']} {filename} > {sha512filename} \n")
            of.write(f"sha512sum --check {sha512filename} \n")
            of.write(f"rm -f {sha512filename} \n")

            # install with confluent-cli
            of.write(f"confluent connect plugin install {filename} --force --worker-configurations /dev/null --plugin-directory /mnt/plugins {plugin['ExtraArgs']} \n")
            of.write(f"rm -vf {filename} \n")
os.chmod(output_file, 0o755)
